Module params

Module params 

Data functionality for Forcefield params. Includes Amber parameters built in to binaries which use this library, and can load params for other sets as required.

Uses bio_files for the base data structures.

Structs

FfParamSet
A set of general parameters that aren’t molecule-specific. E.g. from GAFF2, OL3, RNA, or amino19. These are used as a baseline, and in some cases, overridden by molecule-specific parameters.
ParamGeneralPaths
Paths for to general parameter files. Used to create a FfParamSet.
ProtFfChargeMapSet
Maps type-in-residue (found in, e.g. mmCIF and PDB files) to Amber FF type, and partial charge. We assume that if one of these is loaded, so are the others. So, these aren’t Optionss, but the field that holds this struct should be one.

Constants

AMINO_19
LIPID_21_LIB
OL24_LIB
RNA_LIB

Functions

populate_peptide_ff_and_q
Populate forcefield type, and partial charge on atoms. This should be run on mmCIF files prior to running molecular dynamics on them. These files from RCSB PDB do not natively have this data.
prepare_peptide
Combines several functions that should be run after loading protein files from PDB. Add hydrogens, load force field parameters and partial charge, and add bonds.
prepare_peptide_mmcif
See docs on prepare_peptide. This is a convenience variant that uses an MmCif file.

Type Aliases

LipidFfChargeMap
NucleicAcidFfChargeMap
ProtFfChargeMap