Module partial_charge_inference

Module partial_charge_inference 

For inferring partial charge of small organic molecules using Amber’s GeoStd library as training data. Uses a neural net. Force field types must be assigned prior to running this, e.g. from the param_inference module.

Functions

infer_charge
Infer partial charge for each atom.