Module snapshot

Module snapshot 

Related to storing snapshots (also known as trajectories) of MD runs.

Structs

HydrogenBond
Used for visualizing hydrogen bonds on a given snapshot.
Snapshot
This stores the positions and velocities of all atoms in the system, and the total energy. It represents the output of the simulation. A set of these can be used to play it back over time. We save load and save this to disk in the __ format.
SnapshotEnergyData
Pressure, temperature, energy, etc. Could also be described as thermodynamic properties.
SnapshotHandlers
For saving snapshots.

Enums

HBondAtomType
Used for visualizing hydrogen bonds on a given snapshot.

Functions

gromacs_frames_to_ss
Convert GROMACS trajectory frames into Snapshot values. This converts positions in nm and velocities in nm/ps to Å, and Å/ps
ss_to_gromacs_frames
Convert Snapshot values into GROMACS trajectory frames.