pub enum HBondAtomType {
Standard,
WaterO,
WaterH0,
WaterH1,
}Expand description
Used for visualizing hydrogen bonds on a given snapshot. We distinguish this, as we handle water molecules separately in our state.
Variants