pub struct Snapshot {
pub time: f64,
pub atom_posits: Vec<Vec3>,
pub atom_velocities: Option<Vec<Vec3>>,
pub energy_data: Option<SnapshotEnergyData>,
pub water_o_posits: Vec<Vec3>,
pub water_h0_posits: Vec<Vec3>,
pub water_h1_posits: Vec<Vec3>,
pub water_velocities: Option<Vec<Vec3>>,
}Expand description
This stores the positions and velocities of all atoms in the system, and the total energy. It represents the output of the simulation. A set of these can be used to play it back over time. We save load and save this to disk in the __ format.
Fields
time: f64atom_posits: Vec<Vec3>atom_velocities: Option<Vec<Vec3>>energy_data: Option<SnapshotEnergyData>water_o_posits: Vec<Vec3>water_h0_posits: Vec<Vec3>water_h1_posits: Vec<Vec3>water_velocities: Option<Vec<Vec3>>Single velocity per solvent molecule, as it’s rigid.
Implementations
Sourceimpl Snapshot
impl Snapshot
Sourcepub fn new(state: &MdState) -> Self
pub fn new(state: &MdState) -> Self
Initialize with position data only. We construct these with positions only, then augment with velocity and energy data as required.
pub fn update_with_velocities(&mut self, state: &MdState)
pub fn update_with_energy( &mut self, state: &MdState, pressure: f32, temperature: f32, )
Sourcepub fn unflatten(
&self,
mol_start_indices: &[usize],
) -> Result<Vec<Vec<(Vec3, Vec3)>>>
pub fn unflatten( &self, mol_start_indices: &[usize], ) -> Result<Vec<Vec<(Vec3, Vec3)>>>
Unflatten positions and velocities into a per-molecule basis. mol_start_indices may be
taken directly from MdState. Inner: (Posit, Vel). Does not unflatten the solvent, which is placed
after all non-solvent molecules in the flat arrays.
Sourcepub fn populate_hydrogen_bonds(&mut self, _atoms: &[AtomDynamics])
pub fn populate_hydrogen_bonds(&mut self, _atoms: &[AtomDynamics])
The element indices must match the atom posits.
pub fn to_dcd(&self, cell: &SimBox, write_water: bool) -> DcdFrame
Sourcepub fn from_dcd(dcd: &DcdTrajectory) -> Vec<Self>
pub fn from_dcd(dcd: &DcdTrajectory) -> Vec<Self>
Note: Most of our fields are not available in the DCD format, so we leave them empty, using the Default impl.
Sourceimpl Snapshot
impl Snapshot
pub fn make_mol2( &self, atoms_: &[AtomGeneric], bonds: &[BondGeneric], ) -> Result<Mol2>
pub fn make_mmcif( &self, atoms_: &[AtomGeneric], _bonds: &[BondGeneric], ) -> Result<MmCif>