pub struct AtomDynamics {}Expand description
A trimmed-down atom for use with molecular dynamics. Contains parameters for single-atom, but we use ParametersIndex for multi-atom parameters.
Fields
serial_number: u32static_: boolSources that affect atoms in the system, but are not themselves affected by it. E.g. in docking, this might be a rigid receptor. They serve as sources for Coulomb and LJ (non-bonded) interactions, and as anchors for bonded ones.
bonded_only: boolIf true, this atom exerts and experiences non-bonded forces only. This may be useful for protein atoms that aren’t near a docking site.
force_field_type: Stringelement: Elementposit: Vec3vel: Vec3Å / ps
accel: Vec3Å / ps²
force: Vec3Å • amu / ps²
mass: f32Daltons or amu
partial_charge: f32Amber charge units. This is not the elementary charge units found in amino19.lib and gaff2.dat; it’s scaled by the electrostatic constant.
lj_sigma: f32Å
lj_eps: f32kcal/mol
Implementations
Sourceimpl AtomDynamics
impl AtomDynamics
pub fn new( atom: &AtomGeneric, atom_posits: &[Vec3], i: usize, static_: bool, bonded_only: bool, ) -> Result<Self, ParamError>