MolDynamics

Struct MolDynamics 

pub struct MolDynamics {
    pub ff_mol_type: FfMolType,
    pub atoms: Vec<AtomGeneric>,
    pub atom_posits: Option<Vec<Vec3>>,
    pub atom_init_velocities: Option<Vec<Vec3>>,
    pub bonds: Vec<BondGeneric>,
    pub adjacency_list: Option<Vec<Vec<usize>>>,
    pub static_: bool,
    pub mol_specific_params: Option<ForceFieldParams>,
    pub bonded_only: bool,
}
Packages information required to perform dynamics on a Molecule. This is used to initialize the simulation with atoms and related; one or more of these is passed at init.

Fields

ff_mol_type: FfMolTypeatoms: Vec<AtomGeneric>

These must hold force field type and partial charge.

atom_posits: Option<Vec<Vec3>>

Separate from atoms; this may be more convenient than mutating the atoms as they may move! If None, we use the positions stored in the atoms.

atom_init_velocities: Option<Vec<Vec3>>

This may have uses if “shooting” a molecule into a docking position?

bonds: Vec<BondGeneric>

Not required if static.

adjacency_list: Option<Vec<Vec<usize>>>

A fast lookup for finding atoms, by index, covalently bonded to each atom. If None, will be generated automatically from atoms and bonds. Use this if you wish to cache.

static_: bool

If true, the atoms in the molecule don’t move, but exert LJ and Coulomb forces on other atoms in the system.

mol_specific_params: Option<ForceFieldParams>

If present, any values here override molecule-type general parameters.

bonded_only: bool

todo experimentin If true, this atom exerts and experiences non-bonded forces only. This may be useful for protein atoms that aren’t near a docking site.

Implementations

Source

impl MolDynamics

pub fn from_mol2( mol: &Mol2, mol_specific_params: Option<ForceFieldParams>, ) -> Self

Load a molecule from a Mol2 file. Includes optional molecule-specific pararmeters. To work directly, this assumes that forcefield names, and partial charge are present in the Mol2 struct for all atoms.

You may wish to modify the atom_posits field after to position this relative to other molecules.

Examples found in repository?
examples/minimal.rs (line 29)
11fn main() {
12    let dev = ComputationDevice::Cpu;
13    let param_set = FfParamSet::new_amber().unwrap();
14
15    let mut protein = MmCif::load(Path::new("1c8k.cif")).unwrap();
16    let mol = Mol2::load(Path::new("CPB.mol2")).unwrap();
17
18    // Add Hydrogens, force field type, and partial charge to atoms in the protein; these usually aren't
19    // included from RSCB PDB. You can also call `populate_hydrogens_dihedrals()`, and
20    // `populate_peptide_ff_and_q() separately. Add bonds.
21    let (_bonds, _dihedrals) = prepare_peptide_mmcif(
22        &mut protein,
23        &param_set.peptide_ff_q_map.as_ref().unwrap(),
24        7.0,
25    )
26    .unwrap();
27
28    let mols = vec![
29        MolDynamics::from_mol2(&mol, None),
30        MolDynamics {
31            ff_mol_type: FfMolType::Peptide,
32            atoms: protein.atoms.clone(),
33            static_: true,
34            ..Default::default()
35        },
36    ];
37
38    let (mut md, _) = MdState::new(&dev, &MdConfig::default(), &mols, &param_set).unwrap();
39
40    let n_steps = 100;
41    let dt = 0.002; // picoseconds.
42
43    for _ in 0..n_steps {
44        md.step(&dev, dt, None);
45    }
46
47    let snap = &md.snapshots[md.snapshots.len() - 1]; // A/R.
48    let energy = snap.energy_data.as_ref().unwrap();
49    println!(
50        "KE: {}, PE: {}, Atom posits:",
51        energy.energy_kinetic, energy.energy_potential
52    );
53    for posit in &snap.atom_posits {
54        println!("Posit: {posit}");
55        // Also keeps track of velocities, and solvent molecule positions/velocity
56    }
57
58    // Do something with snapshot data, like displaying atom positions in your UI.
59    // You can save to DCD file, and adjust the ratio they're saved at using the `MdConfig.snapshot_setup`
60    // field: See the example below.
61    for _snap in &md.snapshots {}
62}
pub fn from_sdf( mol: &Sdf, mol_specific_params: Option<ForceFieldParams>, ) -> Self

Load a molecule from a SDF file. Includes optional molecule-specific pararmeters. To work directly, this assumes that forcefield names, and partial charge are present in the Mol2 struct for all atoms. Note that these are not present in SDF files that come from most online databases.

You may wish to modify the atom_posits field after to position this relative to other molecules.

pub fn from_amber_geostd(ident: &str) -> Result<Self>

Load an Amber Geostd molecule from an online database, from its unique identifier. This includes molecule-specific parameters.

You may wish to modify the atom_posits field after to position this relative to other molecules.